@@ -38,6 +38,7 @@ class PaymentechResource(BaseModel):
             params['exclude'] = exclude
 
         dataset = self.dict(
+            exclude_none=True,
             by_alias=True,
             **params
         )
@@ -55,11 +56,11 @@ class PaymentechResource(BaseModel):
         payload = self.serialize(include=include, exclude=exclude)
         trace, result = service.request(payload)
         dataset = self.process_result(result)
+        self.assign(dataset)
 
         if validate:
             self.validate_response(dataset)
 
-        self.assign(dataset)
         self.set_last_trace(trace)
 
         return result
@@ -100,7 +101,7 @@ class PaymentechResource(BaseModel):
             }
 
             message = cvv_lookup.get(cvv_resp_code)
-            raise exceptions.PaymentechException(message, "avs", cvv_resp_code, result)
+            raise exceptions.PaymentechException(message, "cvv", cvv_resp_code, result)
 
         profile_proc_status = result.get("ProfileProcStatus", None)
         if profile_proc_status not in (None, 0, "0", "00"):
